$:.unshift File.expand_path('../../lib', __FILE__)

require 'pp'
require "active_support/all"

require "sms/version"
require "sms/zucp"
require "sms/taobao"

require 'redis' unless defined? Redis
require 'yaml' unless defined? YMAL

def redis
  if $redis && $redis.class.to_s =~ /Redis/
    $redis
  else
    Redis.new(host: 'localhost', port: 6379)
  end
end

def load_config
  if defined? ::Rails
    @sms_config ||= HashWithIndifferentAccess.new(YAML.load_file("#{::Rails.root}/config/sms.yml")[::Rails.env] || {})
  else
    {}
  end
end

class SmsSender

  SOURCES = %w(zucp taobao)

  attr_accessor :source

  def initialize(options = {})
    options[:source] = redis.get('sms:source') || SOURCES.first if options[:source].blank?
    return unless options[:source].in?(SOURCES)

    if load_config.present? && load_config[options[:source]].present?
      options = load_config[options[:source]].merge(options)
    end
    options = HashWithIndifferentAccess.new(options)

    @source = "Sms/#{options[:source]}".camelize.constantize.new(options)
  end

  def content_must_exits?
    case source
      when 'zucp'
        true
      else
        false
    end
  end

  def singleSend(number, content = nil)
    return unless @source
    return unless number.present?
    call = content_must_exits? ? content.present? : true
    @source.singleSend(number, content) if call
  end

  def batchSend(numbers, content = nil)
    return unless @source
    _numbers = numbers.is_a?(String) ? numbers.split(',') : (numbers.is_a?(Array) ? numbers : [])
    _numbers = _numbers.compact.uniq
    return unless _numbers.present?
    call = content_must_exits? ? content.present? : true
    @source.batchSend(_numbers, content) if call
  end

end

if defined? ::Rails
  module Sms
    module Rails
      class Railtie < ::Rails::Railtie
        rake_tasks do
          load "tasks/sms.rake"
        end
      end
    end
  end
end